@@ -17,13 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __ATK_RELATION_SET_H__
-#define __ATK_RELATION_SET_H__
-
 #if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined (__ATK_H_INSIDE__) && !defined (ATK_COMPILATION)
 #error "Only <atk/atk.h> can be included directly."
 #endif
 
+#ifndef __ATK_RELATION_SET_H__
+#define __ATK_RELATION_SET_H__
+
 G_BEGIN_DECLS
 
 #include <glib-object.h>
@@ -55,33 +55,23 @@ struct _AtkRelationSetClass
   AtkFunction pad2;
 };
 
-ATK_AVAILABLE_IN_ALL
 GType atk_relation_set_get_type (void);
 
-ATK_AVAILABLE_IN_ALL
 AtkRelationSet* atk_relation_set_new                  (void);
-ATK_AVAILABLE_IN_ALL
 gboolean        atk_relation_set_contains             (AtkRelationSet  *set,
                                                        AtkRelationType relationship);
-ATK_AVAILABLE_IN_ALL
 gboolean        atk_relation_set_contains_target      (AtkRelationSet  *set,
                                                        AtkRelationType relationship,
-                                                       AtkObject       *target);
-ATK_AVAILABLE_IN_ALL
+                                                       AtkObject       *targe);
 void            atk_relation_set_remove               (AtkRelationSet  *set,
                                                        AtkRelation     *relation);
-ATK_AVAILABLE_IN_ALL
 void            atk_relation_set_add                  (AtkRelationSet  *set,
                                                        AtkRelation     *relation);
-ATK_AVAILABLE_IN_ALL
 gint            atk_relation_set_get_n_relations      (AtkRelationSet  *set);
-ATK_AVAILABLE_IN_ALL
 AtkRelation*    atk_relation_set_get_relation         (AtkRelationSet  *set,
                                                        gint            i);
-ATK_AVAILABLE_IN_ALL
 AtkRelation*    atk_relation_set_get_relation_by_type (AtkRelationSet  *set,
                                                        AtkRelationType relationship);
-ATK_AVAILABLE_IN_ALL
 void            atk_relation_set_add_relation_by_type (AtkRelationSet  *set,
                                                        AtkRelationType relationship,
                                                        AtkObject       *target);
